@@ -1,4 +1,4 @@
-/*      $Id: placement.c 29685 2009-03-27 15:55:13Z olivier $
+/*      $Id$
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
         MA 02110-1301, USA.
 
 
-        xfwm4    - (c) 2002-2009 Olivier Fourdan
+        xfwm4    - (c) 2002-2011 Olivier Fourdan
 
  */
 
@@ -38,9 +38,10 @@
 #include "frame.h"
 #include "netwm.h"
 
+
 /* Compute rectangle overlap area */
 
-static unsigned long
+static inline unsigned long
 segment_overlap (int x0, int x1, int tx0, int tx1)
 {
     if (tx0 > x0)
@@ -58,7 +59,7 @@ segment_overlap (int x0, int x1, int tx0, int tx1)
     return (x1 - x0);
 }
 
-static unsigned long
+static inline unsigned long
 overlap (int x0, int y0, int x1, int y1, int tx0, int ty0, int tx1, int ty1)
 {
     /* Compute overlapping box */
@@ -99,7 +100,8 @@ void
 clientMaxSpace (ScreenInfo *screen_info, int *x, int *y, int *w, int *h)
 {
     Client *c2;
-    int i, delta, screen_width, screen_height;
+    guint i;
+    gint delta, screen_width, screen_height;
 
     g_return_if_fail (x != NULL);
     g_return_if_fail (y != NULL);
@@ -162,7 +164,8 @@ clientCkeckTitle (Client * c)
 {
     Client *c2;
     ScreenInfo *screen_info;
-    int i, frame_x, frame_y, frame_width, frame_top;
+    guint i;
+    gint frame_x, frame_y, frame_width, frame_top;
 
     frame_x = frameX (c);
     frame_y = frameY (c);
@@ -196,11 +199,12 @@ clientConstrainPos (Client * c, gboolean show_full)
 {
     Client *c2;
     ScreenInfo *screen_info;
-    int i, cx, cy, disp_x, disp_y, disp_max_x, disp_max_y;
-    int frame_height, frame_width, frame_top, frame_left;
-    int frame_x, frame_y, frame_visible;
-    int screen_width, screen_height;
-    unsigned int ret;
+    guint i;
+    gint cx, cy, disp_x, disp_y, disp_max_x, disp_max_y;
+    gint frame_height, frame_width, frame_top, frame_left;
+    gint frame_x, frame_y, frame_visible;
+    gint screen_width, screen_height;
+    guint ret;
     GdkRectangle rect;
     gint min_visible;
 
@@ -451,7 +455,6 @@ clientKeepVisible (Client * c, gint n_monitors, GdkRectangle *monitor_rect)
     ScreenInfo *screen_info;
     GdkRectangle rect;
     gboolean centered;
-    int cx, cy;
     int diff_x, diff_y;
     int monitor_nbr;
 
@@ -459,8 +462,6 @@ clientKeepVisible (Client * c, gint n_monitors, GdkRectangle *monitor_rect)
     TRACE ("entering clientKeepVisible");
     TRACE ("client \"%s\" (0x%lx)", c->name, c->window);
 
-    cx = frameX (c) + (frameWidth (c) / 2);
-    cy = frameY (c) + (frameHeight (c) / 2);
     screen_info = c->screen_info;
 
     centered = FALSE;
@@ -503,7 +504,6 @@ static void
 clientAutoMaximize (Client * c, int full_w, int full_h)
 {
     if (FLAG_TEST (c->flags, CLIENT_FLAG_FULLSCREEN) ||
-        FLAG_TEST (c->xfwm_flags, XFWM_FLAG_LEGACY_FULLSCREEN) ||
         !FLAG_TEST (c->xfwm_flags, XFWM_FLAG_HAS_BORDER))
     {
         /*
@@ -538,16 +538,16 @@ smartPlacement (Client * c, int full_x, int full_y, int full_w, int full_h)
     Client *c2;
     ScreenInfo *screen_info;
     gfloat best_overlaps;
-    int test_x, test_y, xmax, ymax, best_x, best_y, i;
-    int frame_x, frame_y, frame_height, frame_width, frame_left, frame_top;
+    guint i;
+    gint test_x, test_y, xmax, ymax, best_x, best_y;
+    gint frame_height, frame_width, frame_left, frame_top;
     gboolean first;
+    gint c2_x, c2_y;
 
     g_return_if_fail (c != NULL);
     TRACE ("entering smartPlacement");
 
     screen_info = c->screen_info;
-    frame_x = frameX (c);
-    frame_y = frameY (c);
     frame_height = frameHeight (c);
     frame_width = frameWidth (c);
     frame_left = frameLeft(c);
@@ -576,14 +576,17 @@ smartPlacement (Client * c, int full_x, int full_y, int full_w, int full_h)
                     && (c->win_workspace == c2->win_workspace)
                     && FLAG_TEST (c2->xfwm_flags, XFWM_FLAG_VISIBLE))
                 {
+                    c2_x = frameX (c2);
+                    c2_y = frameY (c2);
+
                     count_overlaps += overlap (test_x - frame_left,
                                                test_y - frame_top,
                                                test_x - frame_left + frame_width,
                                                test_y - frame_top + frame_height,
-                                               frameX (c2),
-                                               frameY (c2),
-                                               frameX (c2) + frameWidth (c2),
-                                               frameY (c2) + frameHeight (c2));
+                                               c2_x,
+                                               c2_y,
+                                               c2_x + frameWidth (c2),
+                                               c2_y + frameHeight (c2));
                 }
             }
             if (count_overlaps < 0.1)
@@ -629,7 +632,7 @@ static void
 mousePlacement (Client * c, int full_x, int full_y, int full_w, int full_h, int mx, int my)
 {
     g_return_if_fail (c != NULL);
-    TRACE ("entering centerPlacement");
+    TRACE ("entering mousePlacement");
 
     c->x = mx + frameLeft(c) - frameWidth(c) / 2;
     c->y = my + frameTop(c) - frameHeight(c) / 2;
@@ -660,7 +663,7 @@ clientInitPosition (Client * c)
     msy = 0;
     position = (c->size->flags & (PPosition | USPosition));
 
-    n_monitors = gdk_screen_get_n_monitors (c->screen_info->gscr);
+    n_monitors = myScreenGetNumMonitors (c->screen_info);
     if ((n_monitors > 1) || (screen_info->params->placement_mode == PLACE_MOUSE))
     {
         getMouseXY (screen_info, screen_info->xroot, &msx, &msy);
@@ -747,7 +750,6 @@ void
 clientFill (Client * c, int fill_type)
 {
     ScreenInfo *screen_info;
-    DisplayInfo *display_info;
     Client *east_neighbour;
     Client *west_neighbour;
     Client *north_neighbour;
@@ -756,8 +758,9 @@ clientFill (Client * c, int fill_type)
     GdkRectangle rect;
     XWindowChanges wc;
     unsigned short mask;
-    int i, cx, cy, full_x, full_y, full_w, full_h;
-    int tmp_x, tmp_y, tmp_w, tmp_h;
+    guint i;
+    gint cx, cy, full_x, full_y, full_w, full_h;
+    gint tmp_x, tmp_y, tmp_w, tmp_h;
 
     g_return_if_fail (c != NULL);
     TRACE ("entering clientFill");
@@ -768,7 +771,6 @@ clientFill (Client * c, int fill_type)
     }
 
     screen_info = c->screen_info;
-    display_info = screen_info->display_info;
     mask = 0;
     east_neighbour = NULL;
     west_neighbour = NULL;
